Struct jsonrpc_sys::ErrorCode
source · pub struct ErrorCode(pub i64);Expand description
A JSON-RPC 2.0 error code.
Tuple Fields
0: i64Implementations
sourceimpl ErrorCode
impl ErrorCode
sourcepub const PARSE_ERROR: ErrorCode = _
pub const PARSE_ERROR: ErrorCode = _
The error code returned when the server cannot parsed the request.
sourcepub const INVALID_REQUEST: ErrorCode = _
pub const INVALID_REQUEST: ErrorCode = _
The error code returned when the request is not a valid JSON-RPC 2.0 request.
sourcepub const METHOD_NOT_FOUND: ErrorCode = _
pub const METHOD_NOT_FOUND: ErrorCode = _
The error code returned when the method does not exist.
sourcepub const INVALID_PARAMS: ErrorCode = _
pub const INVALID_PARAMS: ErrorCode = _
The error code returned when the parameters are invalid.
sourcepub const INTERNAL_ERROR: ErrorCode = _
pub const INTERNAL_ERROR: ErrorCode = _
The error code returned when an internal error occurs.